@@ -1,6 +1,30 @@
 # Function to output the data frame
 
-output_df <- function(est_eff, beta_threshhold, unstd_beta, bias = NULL, sustain = NULL, recase, obs_r, critical_r, r_con, itcv, non_linear) {
+#' Output data frame based on model estimates and thresholds
+#'
+#' @param est_eff estimated effect
+#' @param beta_threshhold threshold for beta
+#' @param unstd_beta unstandardized beta value
+#' @param bias bias to change inference
+#' @param sustain sustain to change inference
+#' @param recase number of cases to replace null
+#' @param obs_r observed correlation
+#' @param critical_r critical correlation
+#' @param r_con correlation for omitted variable
+#' @param itcv inferential threshold for confounding variable
+#' @param non_linear flag for non-linear models
+#' @return data frame with model information
+#' @importFrom dplyr tibble
+output_df <- function(est_eff, 
+                      beta_threshhold,
+                      unstd_beta, 
+                      bias = NULL, 
+                      sustain = NULL, 
+                      recase, obs_r, 
+                      critical_r, 
+                      r_con, 
+                      itcv, 
+                      non_linear) {
   if (abs(est_eff) > abs(beta_threshhold)) {
     df <- dplyr::tibble(
       action = "to_invalidate",
